@@ -3,7 +3,12 @@ from pathlib import Path
 from tempfile import TemporaryDirectory
 from typing import TYPE_CHECKING
 
-from ..cloudpath import CloudPath, register_path_class
+try:
+    from azure.core.exceptions import ResourceNotFoundError
+except ImportError:
+    pass
+
+from ..cloudpath import CloudPath, NoStat, register_path_class
 
 
 if TYPE_CHECKING:
@@ -42,7 +47,10 @@ class AzureBlobPath(CloudPath):
             tf.cleanup()
 
     def stat(self):
-        meta = self.client._get_metadata(self)
+        try:
+            meta = self.client._get_metadata(self)
+        except ResourceNotFoundError:
+            raise NoStat(f"No stats available for {self}; it may be a directory or not exist.")
 
         return os.stat_result(
             (
